# yumcheck

yumchek is a python library to validate if a yum package is installed and which vendor ships the package.

## Installation

Use the package manager [pip3](https://pip.pypa.io/en/stable/) to install yumcheck.

```bash
pip3 install yumcheck
```